==> glexec-0.8.10.tar.gz: glexec-0.8.10/src/glexec_lcas.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 * Authors: Oscar Koeroo, Mischa Sall\'e
 *      NIKHEF Amsterdam, the Netherlands
 *      <grid-mw-security@nikhef.nl>  
 */

/*
 * \file glexec_lcas.h
 * provides the functionality to dynamically open lcas and its API
 */

#ifndef _GLEXEC_LCAS_H
#define _GLEXEC_LCAS_H

/* For type FILE */
#include <stdio.h>

/*************************************************************************/
/* LCAS DEFAULTS							 */
/*************************************************************************/

/* Default db file is set in configure */

#ifndef LCAS_LOG_FILE
#define LCAS_LOG_FILE "/var/log/glexec/lcas_lcmaps.log"
#endif

#ifndef LCAS_DEBUG_LEVEL
#define LCAS_DEBUG_LEVEL   "0"
#endif

#ifndef LCAS_LIBDIR
#define LCAS_LIBDIR	""
#endif

#ifndef LIBSUFF
 #ifdef __APPLE__
  #define LIBSUFF	".dylib"
 #else
  #define LIBSUFF	".so"
 #endif
#endif

/*************************************************************************/
/* FUNCTION DECLARATIONS                                                 */
/*************************************************************************/

/*
 * Setup, run and close LCAS for given rsl.
 * returns GLEXEC_SUCCESS when successful
 */
int glexec_lcas(char *pem_string, char *logstring, char *rsl);

/*
 * Print the known LCAS defines to given open file descriptor.
 */
void glexec_lcas_defines(FILE *out);

#endif

==> glexec_0.9.8.orig.tar.gz: glexec-0.9.8/src/glexec_lcas.h <==
/**
 * Copyright (c) Members of the EGEE Collaboration. 2010. 
 * See http://www.eu-egee.org/partners/ for details on the copyright
 * holders.  
 * 
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License.
 *
 * Authors: Oscar Koeroo, Mischa Sall\'e
 *      NIKHEF Amsterdam, the Netherlands
 *      <grid-mw-security@nikhef.nl>  
 */

/*
 * \file glexec_lcas.h
 * provides the functionality to dynamically open lcas and its API
 */

#ifndef _GLEXEC_LCAS_H
#define _GLEXEC_LCAS_H

/* For type FILE */
#include <stdio.h>

/*************************************************************************/
/* LCAS DEFAULTS							 */
/*************************************************************************/

/* Default db file is set in configure */

#ifndef LCAS_LOG_FILE
#define LCAS_LOG_FILE "/var/log/glexec/lcas_lcmaps.log"
#endif

#ifndef LCAS_DEBUG_LEVEL
#define LCAS_DEBUG_LEVEL   "4"
#endif

#ifndef LCAS_LIBDIR
#define LCAS_LIBDIR	""
#endif

#ifndef LIBSUFF
 #ifdef __APPLE__
  #define LIBSUFF	".dylib"
 #else
  #define LIBSUFF	".so"
 #endif
#endif

/*************************************************************************/
/* FUNCTION DECLARATIONS                                                 */
/*************************************************************************/

/*
 * Setup, run and close LCAS for given rsl.
 * returns GLEXEC_SUCCESS when successful
 */
int glexec_lcas(char *pem_string, char *rsl);

/*
 * Print the known LCAS defines to given open file descriptor.
 */
void glexec_lcas_defines(FILE *out);

#endif
